@@ -1694,7 +1694,7 @@ class Update(MethodsInterface):
         return f"{host}level{level_required}"
 
     @variable_module("update")
-    def detect_best_binhost(self):
+    def detect_best_binhost(self, cl_check_update_level):
         # выполняется переход с серверов unstable обновлении на stable
         # в этом случае не важно, что бинари могут старее текущих
         if (self.clVars.GetBool('cl_update_binhost_stable_opt_set') and
@@ -1702,7 +1702,9 @@ class Update(MethodsInterface):
             stabilization = True
         else:
             stabilization = False
-        ignore_level = self.clVars.Get("cl_check_update_level") == Variable.Off
+        #had to extract ignore level logic to cl_update because of variable module
+        ignore_level = not cl_check_update_level
+        # ignore_level = self.clVars.Get('cl_check_update_level') == Variable.Off
         current_level_is_valid = self.check_current_level() if not ignore_level else None
         self.startTask(_("Searching new binhost"))
         retval = self._search_best_binhost(self.binhosts_data,
