@@ -73,7 +73,7 @@ def get_synchronization_tasks(object_name):
               'tasks': [
                  # найти лучший сервер обновлений
                  {'name': 'detect_best_binhost',
-                  'method': Object('detect_best_binhost()'),
+                  'method': Object(f'detect_best_binhost({object_name.lower()}.cl_check_update_level)'),
                   'essential': False,
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
                              (~AllTasks.success_one_of("check_current_binhost") |
@@ -123,7 +123,7 @@ def get_synchronization_tasks(object_name):
                  {'name': 'sync_reps:update_packages_cache',
                   'message': __("Update packages index"),
                   'method': Object('download_packages(update.cl_update_portage_binhost,'
-                            'update.cl_update_package_cache,update.cl_update_package_cache_sign,'
+                            'update.cl_update_package_cache, update.cl_update_package_cache_sign,'
                             'update.cl_update_gpg)'),
                   'essential': False,
                   'condition': lambda Get, GetBool: (
